# -*- coding: utf-8 -*-
"""
    avrsim
    ~~~~~~

    MyHDL simulator for AVR chips
"""

__all__ = (
    "__title__","__version__","__url__","__summary__",
    "__author__","__email__","__license__","__copyright__",
)

__title__   =   "AVRsim"
__version__ =   "0.1.0"
__url__     =   "https://github.com/rblack42/avrsim"
__summary__ =   "An MyHDL simulator for AVR chips"
__author__  =   "Roie R. Black"
__email__   =   "rblack@austincc.edu"
__license__ =   "BSD 3-Clause"
__copyright__   = "Copyright 2016 Roie R. Black"
